{ config, lib, pkgs, inputs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../server.nix
  ];

  networking.hostId = "731d1660";

  hardware = {
    raspberry-pi."4" = {
      apply-overlays-dtmerge.enable = true;
      audio.enable = false;
      fkms-3d.enable = true;
      xhci.enable = true;
    };
    deviceTree = {
      enable = true;
      overlays = [
        { name = "hifiberry-digi-pro"; dtboFile = "${pkgs.device-tree_rpi.overlays}/hifiberry-digi-pro.dtbo"; }
      ];
    };
    firmware = with pkgs; [
      firmwareLinuxNonfree
      wireless-regdb
    ];
  };

  sound.enable = true;
  console.enable = false;

  age.secrets."passwords/networks.age" = {
    file = "${inputs.secrets}/passwords/networks.age";
  };

  networking = {
    wireless = {
      enable = true;
      interfaces = [ "wlan0" ];
      environmentFile = config.age.secrets."passwords/networks.age".path;
      networks = {
        "Apollo 600 Mbps".psk = "@PSK_APOLLO@";
      };
    };
  };

  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    systemWide = true;
  };

  services.shairport-sync = {
    enable = true;
    group = "pipewire";
    openFirewall = true;
  };

  services.zigbee2mqtt = {
    enable = true;
    settings = {
      homeassistant = true;
      frontend = true;
      permit_join = true;
    };
  };

  environment.systemPackages = with pkgs; [
    libraspberrypi
    raspberrypi-eeprom
  ];

  system.stateVersion = "22.11";
}

